# SPARKS - Software for Polymerization and Reaction Kinetics Simulations

**SPaRKS** is a highly-modular framework for deterministic and stochastic simulations of polymerization and general reaction kinetics. It provides a unified interface to define and compare models and simulators, and parameter estimation. Written in Python.

[![PyPI](https://badge.fury.io/py/pysparks.svg)](https://badge.fury.io/py/pysparks)
[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.17172057.svg)](https://doi.org/10.5281/zenodo.17172057)
[![Python](https://img.shields.io/badge/Python-%3E%3D3.10-blue?logo=python&logoColor=yellow)](https://python.org)


## Quick install
The easiest way to install **SPaRKS** is via pip:

```shell
pip3 install pysparks
```

## Examples

There are jupyter notebooks in the [docs/notebooks](docs/notebooks/) directory. More relevant examples can be found at the supporting data for the manuscript below. This can be found at [this repository](https://github.com/devoncallan/ReversibleCopolymerizations): [![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.17172057.svg)](https://doi.org/10.5281/zenodo.17172057)

## How to Cite

**Citeable DOI for this version of SPaRKS:** [![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.17172075.svg)](https://doi.org/10.5281/zenodo.17172075)

If you use SPaRKS in your project, please cite
* Callan, D. H., and Bates, C. M. Efficient Deterministic Modeling of Reversile Copolymerizations, *Macromolecules*, **2025**, XXX, XXX-XXX, [doi:10.1021/acs.macromol.5c01421](https://doi.org/10.1021/acs.macromol.5c01421)